@@ -15,12 +15,7 @@ class TestDcEnergyMeter:
         assert actual.get_voltage() == 12.52
         assert actual.get_starter_voltage() == -0.01
 
-        assert actual.get_high_starter_battery_voltage_alarm() == False
-        assert actual.get_low_starter_battery_voltage_alarm() == False
-        assert actual.get_high_voltage_alarm() == False
-        assert actual.get_low_voltage_alarm() == False
-        assert actual.get_high_temperature_alarm() == False
-        assert actual.get_low_temperature_alarm() == False
+        assert actual.get_alarm() == None
 
         assert actual.get_temperature() == None
         assert actual.get_model_name() == "SmartShunt 500A/50mV"
